# Changelog

## 0.1.0-alpha.1 (2025-03-06)

Full Changelog: [v0.0.1-alpha.1...v0.1.0-alpha.1](https://github.com/ShortGenius/shortgenius-sdk-python/compare/v0.0.1-alpha.1...v0.1.0-alpha.1)

### Features

* **api:** add code samples ([#5](https://github.com/ShortGenius/shortgenius-sdk-python/issues/5)) ([b4551bb](https://github.com/ShortGenius/shortgenius-sdk-python/commit/b4551bba2c0c564839e20318acb3377cfbc29bb4))
* **api:** api update ([#10](https://github.com/ShortGenius/shortgenius-sdk-python/issues/10)) ([e4b2898](https://github.com/ShortGenius/shortgenius-sdk-python/commit/e4b28987b783c1980613a47a8c1b5095cf4c3b9c))


### Chores

* **docs:** update client docstring ([#8](https://github.com/ShortGenius/shortgenius-sdk-python/issues/8)) ([f3ab1a3](https://github.com/ShortGenius/shortgenius-sdk-python/commit/f3ab1a3fdae25f96926c571747fd8bf73b273830))
* **internal:** remove unused http client options forwarding ([#9](https://github.com/ShortGenius/shortgenius-sdk-python/issues/9)) ([73777c9](https://github.com/ShortGenius/shortgenius-sdk-python/commit/73777c924ebd69f1a621eb8af872f2f5bcc865cb))


### Documentation

* update URLs from stainlessapi.com to stainless.com ([#7](https://github.com/ShortGenius/shortgenius-sdk-python/issues/7)) ([6c825ad](https://github.com/ShortGenius/shortgenius-sdk-python/commit/6c825addf5f75025c71325209f3637b1f95c7939))

## 0.0.1-alpha.1 (2025-02-25)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/ShortGenius/shortgenius-sdk-python/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* go live ([#1](https://github.com/ShortGenius/shortgenius-sdk-python/issues/1)) ([d3c8bc1](https://github.com/ShortGenius/shortgenius-sdk-python/commit/d3c8bc19fe069344ce7bbbdfd8ecc6ef56ce19d7))
* update SDK settings ([#3](https://github.com/ShortGenius/shortgenius-sdk-python/issues/3)) ([fdd8c1f](https://github.com/ShortGenius/shortgenius-sdk-python/commit/fdd8c1f4e52329eefca1037e67df809fe4c169fe))
